@@ -46,6 +46,8 @@ template<typename eT> class SpMat;
 template<typename eT> class SpCol;
 template<typename eT> class SpRow;
 template<typename eT> class SpSubview;
+template<typename eT> class SpSubview_col;
+template<typename eT> class SpSubview_row;
 
 template<typename eT> class diagview;
 template<typename eT> class spdiagview;
@@ -348,87 +350,22 @@ static const injector_end_of_row<> endr = injector_end_of_row<>();
 enum file_type
   {
   file_type_unknown,
-  auto_detect,        //!< Automatically detect the file type
-  raw_ascii,          //!< ASCII format (text), without any other information.
-  arma_ascii,         //!< Armadillo ASCII format (text), with information about matrix type and size
-  csv_ascii,          //!< comma separated values (CSV), without any other information
-  raw_binary,         //!< raw binary format, without any other information.
-  arma_binary,        //!< Armadillo binary format, with information about matrix type and size
+  auto_detect,        //!< attempt to automatically detect the file type
+  raw_ascii,          //!< raw text (ASCII), without a header
+  arma_ascii,         //!< Armadillo text format, with a header specifying matrix type and size
+  csv_ascii,          //!< comma separated values (CSV), without a header
+  raw_binary,         //!< raw binary format (machine dependent), without a header
+  arma_binary,        //!< Armadillo binary format (machine dependent), with a header specifying matrix type and size
   pgm_binary,         //!< Portable Grey Map (greyscale image)
   ppm_binary,         //!< Portable Pixel Map (colour image), used by the field and cube classes
-  hdf5_binary,        //!< Open binary format, not specific to Armadillo, which can store arbitrary data
-  hdf5_binary_trans,  //!< as per hdf5_binary, but save/load the data with columns transposed to rows
-  coord_ascii         //!< simple co-ordinate format for sparse matrices
+  hdf5_binary,        //!< HDF5: open binary format, not specific to Armadillo, which can store arbitrary data
+  hdf5_binary_trans,  //!< [DO NOT USE - deprecated] as per hdf5_binary, but save/load the data with columns transposed to rows
+  coord_ascii         //!< simple co-ordinate format for sparse matrices (indices start at zero)
   };
 
 
-namespace hdf5_opts
-  {
-  typedef unsigned int flag_type;
-  
-  struct opts
-    {
-    const flag_type flags;
-    
-    inline explicit opts(const flag_type in_flags);
-    
-    inline const opts operator+(const opts& rhs) const;
-    };
-  
-  inline
-  opts::opts(const flag_type in_flags)
-    : flags(in_flags)
-    {}
-  
-  inline
-  const opts
-  opts::operator+(const opts& rhs) const
-    {
-    const opts result( flags | rhs.flags );
-    
-    return result;
-    }
-  
-  // The values below (eg. 1u << 0) are for internal Armadillo use only.
-  // The values can change without notice.
-  
-  static const flag_type flag_none    = flag_type(0      );
-  static const flag_type flag_trans   = flag_type(1u << 0);
-  static const flag_type flag_append  = flag_type(1u << 1);
-  static const flag_type flag_replace = flag_type(1u << 2);
-  
-  struct opts_none    : public opts { inline opts_none()    : opts(flag_none   ) {} };
-  struct opts_trans   : public opts { inline opts_trans()   : opts(flag_trans  ) {} };
-  struct opts_append  : public opts { inline opts_append()  : opts(flag_append ) {} };
-  struct opts_replace : public opts { inline opts_replace() : opts(flag_replace) {} };
-  
-  static const opts_none    none;
-  static const opts_trans   trans;
-  static const opts_append  append;
-  static const opts_replace replace;
-  }
-
-
-struct hdf5_name
-  {
-  const std::string     filename;
-  const std::string     dsname;
-  const hdf5_opts::opts opts;
-  
-  inline
-  hdf5_name(const std::string& in_filename)
-    : filename(in_filename    )
-    , dsname  (std::string()  )
-    , opts    (hdf5_opts::none)
-    {}
-  
-  inline
-  hdf5_name(const std::string& in_filename, const std::string& in_dsname, const hdf5_opts::opts& in_opts = hdf5_opts::none)
-    : filename(in_filename)
-    , dsname  (in_dsname  )
-    , opts    (in_opts    )
-    {}
-  };
+struct hdf5_name;
+struct  csv_name;
 
 
 //! @}
@@ -501,7 +438,7 @@ struct superlu_opts : public spsolve_opts_base
     symmetric    = false;
     pivot_thresh = 1.0;
     permutation  = COLAMD;
-    refine       = REF_DOUBLE;
+    refine       = REF_NONE;
     }
   };
 
