@@ -125,14 +125,17 @@
 //// and you will need to link with the hdf5 library (eg. -lhdf5)
 #endif
 
-#if !defined(ARMA_OPTIMISE_SOLVE_BAND)
-  #define ARMA_OPTIMISE_SOLVE_BAND
-  //// Comment out the above line if you don't want optimised handling of band matrices by solve()
+#if !defined(ARMA_OPTIMISE_BAND)
+  #define ARMA_OPTIMISE_BAND
+  //// Comment out the above line if you don't want automatically optimised handling
+  //// of band matrices by solve() and chol()
 #endif
 
-#if !defined(ARMA_OPTIMISE_SOLVE_SYMPD)
-  #define ARMA_OPTIMISE_SOLVE_SYMPD
-  //// Comment out the above line if you don't want optimised handling of symmetric/hermitian positive definite matrices by solve()
+#if !defined(ARMA_OPTIMISE_SYMPD)
+  #define ARMA_OPTIMISE_SYMPD
+  //// Comment out the above line if you don't want automatically optimised handling
+  //// of symmetric/hermitian positive definite matrices by various functions:
+  //// solve(), inv(), expmat(), logmat(), sqrtmat(), rcond()
 #endif
 
 // #define ARMA_USE_HDF5_ALT
@@ -274,12 +277,12 @@
   #undef ARMA_USE_HDF5_ALT
 #endif
 
-#if defined(ARMA_DONT_OPTIMISE_SOLVE_BAND)
-  #undef ARMA_OPTIMISE_SOLVE_BAND
+#if defined(ARMA_DONT_OPTIMISE_BAND) || defined(ARMA_DONT_OPTIMISE_SOLVE_BAND)
+  #undef ARMA_OPTIMISE_BAND
 #endif
 
-#if defined(ARMA_DONT_OPTIMISE_SOLVE_SYMPD)
-  #undef ARMA_OPTIMISE_SOLVE_SYMPD
+#if defined(ARMA_DONT_OPTIMISE_SYMPD) || defined(ARMA_DONT_OPTIMISE_SOLVE_SYMPD)
+  #undef ARMA_OPTIMISE_SYMPD
 #endif
 
 #if defined(ARMA_DONT_PRINT_ERRORS)
@@ -290,6 +293,10 @@
   #undef ARMA_PRINT_HDF5_ERRORS
 #endif
 
+#if defined(ARMA_NO_CRIPPLED_LAPACK)
+  #undef ARMA_CRIPPLED_LAPACK
+#endif
+
 
 // if Armadillo was installed on this system via CMake and ARMA_USE_WRAPPER is not defined,
 // ARMA_AUX_LIBS lists the libraries required by Armadillo on this system, and
