@@ -32,12 +32,17 @@ class op_nonzeros
   
   template<typename T1>
   static inline void apply(Mat<typename T1::elem_type>& out, const Op<T1, op_nonzeros>& X);
-  
-  
-  // for sparse matrices
+  };
+
+
+
+class op_nonzeros_spmat
+  : public traits_op_col
+  {
+  public:
   
   template<typename T1>
-  static inline void apply_noalias(Mat<typename T1::elem_type>& out, const SpBase<typename T1::elem_type, T1>& X);
+  static inline void apply(Mat<typename T1::elem_type>& out, const SpToDOp<T1, op_nonzeros_spmat>& X);
   };
 
 
